@@ -8,8 +8,4 @@ static inline R_len_t vec_size(SEXP x) {
   return short_vec_size(x);
 }
 
-static inline SEXP vec_recycle(SEXP x, R_len_t size) {
-  return short_vec_recycle(x, size);
-}
-
 #endif
